@@ -5,7 +5,7 @@ from shutil import which
 from pathlib import Path
 
 from .common import DomainParams, Energy
-from .simulation import Flow, Search, Shrink
+from .simulation import Simulation, Flow, Search, Shrink
 from .diagram import Diagram
 
 dia_presets = {
@@ -45,13 +45,15 @@ def check_params(container: Dict, needed: List[str], valid: Dict) -> None:
 
 def main():
 	# Loading configuration and settings.
-	parser = argparse.ArgumentParser("PackSim")
+	parser = argparse.ArgumentParser("Squish")
 	parser.add_argument('sim_conf', metavar='/path/to/config.json',
 						help="configuration file for a simulation")
 	parser.add_argument('-q', '--quiet', dest='quiet', action='store_true', default=False,
 						help="suppress all normal output")
 	parser.add_argument('-l', '--log', dest='log_steps', default=50, type=int,
 						help="number of iterations before logging")
+	parser.add_argument('-i', dest='input_file', metavar='/path/to/sim',
+						help="folder that contains outputted simulation files.", default=None)
 
 	parser.add_argument('--n_objects', dest='n', type=int, help="objects in domain")
 	parser.add_argument('--width', dest='w', type=float, help="width of domain")
@@ -60,17 +62,14 @@ def main():
 	parser.add_argument('--energy', dest='energy', help="energy type of system")
 
 	args = parser.parse_args()
-	config_sim(args)
-	# if args.input_file is None:
-	# 	config_sim(args)
-	# else:
-	# 	loaded_sim(args)
+	do_sim(args, args.input_file)
 
 
-def config_sim(args):
+def do_sim(args, file):
 	with open(args.sim_conf) as f:
 		params = json.load(f)
 
+
 	check_params(params, ["domain", "simulation"], {})
 	dmn_params, sim_params = params["domain"], params["simulation"]
 
@@ -105,20 +104,23 @@ def config_sim(args):
 
 	name = sim_params.get("name")
 
-	if mode == "flow":
-		sim = Flow(domain, energy, step, thres, adaptive, name=name)
-	elif mode == "search":
-		check_params(sim_params, ["manifold_step_size", "eq_stop_count"], {
-			"manifold_step_size": "positive", "eq_stop_count": "positive"
-		})
-		sim = Search(domain, energy, step, thres, adaptive, sim_params["manifold_step_size"],
-						sim_params["eq_stop_count"], name=name)
-	elif mode == "shrink":
-		check_params(sim_params, ["width_change", "width_stop"], {
-			"width_change": "positive", "width_stop": "positive"
-		})
-		sim = Shrink(domain, energy, step, thres, adaptive, sim_params["width_change"],
-						sim_params["width_stop"], name=name)
+	if file is None:
+		if mode == "flow":
+			sim = Flow(domain, energy, step, thres, adaptive, name=name)
+		elif mode == "search":
+			check_params(sim_params, ["manifold_step_size", "eq_stop_count"], {
+				"manifold_step_size": "positive", "eq_stop_count": "positive"
+			})
+			sim = Search(domain, energy, step, thres, adaptive, sim_params["manifold_step_size"],
+							sim_params["eq_stop_count"], name=name)
+		elif mode == "shrink":
+			check_params(sim_params, ["width_change", "width_stop"], {
+				"width_change": "positive", "width_stop": "positive"
+			})
+			sim = Shrink(domain, energy, step, thres, adaptive, sim_params["width_change"],
+							sim_params["width_stop"], name=name)
+	else:
+		sim = Simulation.from_file(file)
 
 	save_diagram = False
 	if "diagram" in params:
@@ -139,8 +141,7 @@ def config_sim(args):
 		if "time" not in dia_params:
 			dia_params["time"] = 30
 
-	sim.add_frame(points)
-	sim.run(save_sim, not args.quiet, args.log_steps)
+	sim.run(save_sim, not args.quiet, args.log_steps, points)
 
 	if save_diagram:
 		diagram = Diagram(sim, dia_params["figures"])
@@ -153,9 +154,6 @@ def config_sim(args):
 				diagram.render_video(dia_params["time"], "use_all")
 
 
-def loaded_sim(args):
-	pass
-
 def pre():
 	os.environ["QT_LOGGING_RULES"] = "*=false"
 	try:
